import type { AlgoliaSettings, AlgoliaSearchResponse } from './bundle.types.js';
import type { ClientValidation } from './client.types.js';
export type * from './client.types.js';
export type Settings = Pick<AlgoliaSettings, 'searchableAttributes' | 'attributesForFaceting' | 'attributesToRetrieve' | 'maxValuesPerFacet' | 'sortFacetValuesBy' | 'attributesToHighlight' | 'highlightPreTag' | 'highlightPostTag' | 'hitsPerPage' | 'paginationLimitedTo' | 'numericAttributesForFiltering' | 'maxFacetHits' | 'renderingContent'>;
/**
 * Handler namespace
 */
export declare namespace Handler {
    /**
     * Request and response types
     */
    interface Req {
        body: string | object;
    }
    interface Res {
        status: (code: number) => Res;
        json: (data: object) => void;
    }
    /**
     * Handlers
     */
    type Config = {
        indexName?: string;
        settings?: Settings;
        clientValidation?: ClientValidation;
    };
    type Configs = [Config] | (Config & {
        indexName: string;
    })[];
    type ConfigWithDefaults = Omit<Config, 'clientValidation' | 'settings'> & {
        clientValidation: Required<ClientValidation>;
        settings: Required<Settings>;
    };
}
/**
 * Inferred types - from writing a zod schema then using infer
 */
export declare namespace Inferred {
    type RequestInitial = import('./index.validation.js').RequestInitial;
}
/**
 * Return types
 */
export interface DatabaseHit {
    [key: string]: string | number | boolean | null | undefined;
}
export interface DatabaseResult {
    rows: {
        json: {
            totalHits: number;
            hits: DatabaseHit[];
            facets: {
                [key: string]: {
                    [key: string]: number;
                };
            };
            facets_stats: {
                [key: string]: {
                    min: number;
                    max: number;
                    avg: number;
                    sum: number;
                };
            };
        };
    }[];
}
/**
 * The type of Hit here should be improved
 */
export type Hit = {
    _highlightResult?: {
        [key: string]: {
            value: string;
            matchLevel: 'none' | 'partial' | 'full';
            matchedWords: string[];
            fullyHighlighted?: boolean;
        };
    };
} & {
    [key: string]: string | number | boolean | null | undefined;
};
export type SearchResponse = Pick<AlgoliaSearchResponse<{}>, 'nbHits' | 'page' | 'length' | 'offset' | 'nbPages' | 'hitsPerPage' | 'exhaustiveNbHits' | 'exhaustiveFacetsCount' | 'processingTimeMS' | 'query' | 'params' | 'index' | 'indexUsed' | 'facets_stats' | 'renderingContent'> & {
    hits: Hit[];
};
export type FacetHit = {
    highlighted: string;
    [key: string]: string;
} & {
    count: number;
};
export interface FacetsSearchResponse {
    facetHits: FacetHit[];
}
