import { z } from 'zod';
import type { Handler } from './index.types.js';
/**
 * This file is for validation of the payload from the client
 */
export declare const SearchOptionsSchema: z.ZodObject<{
    query: z.ZodOptional<z.ZodString>;
    attributesToRetrieve: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    facetFilters: z.ZodOptional<z.ZodUnion<[z.ZodArray<z.ZodString, "many">, z.ZodArray<z.ZodArray<z.ZodString, "many">, "many">]>>;
    numericFilters: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    facets: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>>;
    maxValuesPerFacet: z.ZodOptional<z.ZodNumber>;
    sortFacetValuesBy: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"count">, z.ZodLiteral<"alpha">]>>;
    attributesToHighlight: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    highlightPostTag: z.ZodOptional<z.ZodString>;
    highlightPreTag: z.ZodOptional<z.ZodString>;
    page: z.ZodOptional<z.ZodNumber>;
    hitsPerPage: z.ZodOptional<z.ZodNumber>;
    offset: z.ZodOptional<z.ZodNumber>;
    length: z.ZodOptional<z.ZodNumber>;
    maxFacetHits: z.ZodOptional<z.ZodNumber>;
    facetQuery: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    query?: string | undefined;
    attributesToRetrieve?: string[] | undefined;
    facetFilters?: string[] | string[][] | undefined;
    numericFilters?: string[] | undefined;
    facets?: string | string[] | undefined;
    maxValuesPerFacet?: number | undefined;
    sortFacetValuesBy?: "alpha" | "count" | undefined;
    attributesToHighlight?: string[] | undefined;
    highlightPostTag?: string | undefined;
    highlightPreTag?: string | undefined;
    page?: number | undefined;
    hitsPerPage?: number | undefined;
    offset?: number | undefined;
    length?: number | undefined;
    maxFacetHits?: number | undefined;
    facetQuery?: string | undefined;
}, {
    query?: string | undefined;
    attributesToRetrieve?: string[] | undefined;
    facetFilters?: string[] | string[][] | undefined;
    numericFilters?: string[] | undefined;
    facets?: string | string[] | undefined;
    maxValuesPerFacet?: number | undefined;
    sortFacetValuesBy?: "alpha" | "count" | undefined;
    attributesToHighlight?: string[] | undefined;
    highlightPostTag?: string | undefined;
    highlightPreTag?: string | undefined;
    page?: number | undefined;
    hitsPerPage?: number | undefined;
    offset?: number | undefined;
    length?: number | undefined;
    maxFacetHits?: number | undefined;
    facetQuery?: string | undefined;
}>;
/**
 * Input validation with zod
 * Successful validation returns a typed object
 */
/**
 * Initial validation of the payload
 * This is to ensure that the payload is an array of objects
 * with indexName and params
 */
export declare const IndexName: z.ZodString;
declare const RequestSchemaInitial: z.ZodObject<{
    indexName: z.ZodString;
    params: z.ZodAny;
    facet: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodLiteral<"facet">>;
}, "strip", z.ZodTypeAny, {
    indexName: string;
    params?: any;
    facet?: string | undefined;
    type?: "facet" | undefined;
}, {
    indexName: string;
    params?: any;
    facet?: string | undefined;
    type?: "facet" | undefined;
}>;
export declare const initialValidation: (payload: any) => z.SafeParseReturnType<{
    requests: {
        indexName: string;
        params?: any;
        facet?: string | undefined;
        type?: "facet" | undefined;
    }[];
}, {
    requests: {
        indexName: string;
        params?: any;
        facet?: string | undefined;
        type?: "facet" | undefined;
    }[];
}>;
export type RequestInitial = z.infer<typeof RequestSchemaInitial>;
export declare const validatePayload: (request: z.infer<typeof RequestSchemaInitial>, clientValidation: Handler.ConfigWithDefaults['clientValidation'], mergedSettings: Handler.ConfigWithDefaults['settings']) => z.SafeParseReturnType<{
    params: {
        query?: string | undefined;
        attributesToRetrieve?: string[] | undefined;
        facetFilters?: string[] | string[][] | undefined;
        numericFilters?: string[] | undefined;
        facets?: string | string[] | undefined;
        maxValuesPerFacet?: number | undefined;
        sortFacetValuesBy?: "alpha" | "count" | undefined;
        attributesToHighlight?: string[] | undefined;
        highlightPostTag?: string | undefined;
        highlightPreTag?: string | undefined;
        page?: number | undefined;
        hitsPerPage?: number | undefined;
        offset?: number | undefined;
        length?: number | undefined;
        maxFacetHits?: number | undefined;
        facetQuery?: string | undefined;
    };
    indexName: string;
    facet?: string | undefined;
    type?: "facet" | undefined;
} & {
    params: {
        page?: number | undefined;
        hitsPerPage?: number | undefined;
        offset?: number | undefined;
        length?: number | undefined;
    };
}, {
    params: {
        query?: string | undefined;
        attributesToRetrieve?: string[] | undefined;
        facetFilters?: string[] | string[][] | undefined;
        numericFilters?: string[] | undefined;
        facets?: string | string[] | undefined;
        maxValuesPerFacet?: number | undefined;
        sortFacetValuesBy?: "alpha" | "count" | undefined;
        attributesToHighlight?: string[] | undefined;
        highlightPostTag?: string | undefined;
        highlightPreTag?: string | undefined;
        page?: number | undefined;
        hitsPerPage?: number | undefined;
        offset?: number | undefined;
        length?: number | undefined;
        maxFacetHits?: number | undefined;
        facetQuery?: string | undefined;
    };
    indexName: string;
    facet?: string | undefined;
    type?: "facet" | undefined;
} & {
    params: {
        page?: number | undefined;
        hitsPerPage?: number | undefined;
        offset?: number | undefined;
        length?: number | undefined;
    };
}>;
declare const _default: {
    initial: (payload: any) => z.SafeParseReturnType<{
        requests: {
            indexName: string;
            params?: any;
            facet?: string | undefined;
            type?: "facet" | undefined;
        }[];
    }, {
        requests: {
            indexName: string;
            params?: any;
            facet?: string | undefined;
            type?: "facet" | undefined;
        }[];
    }>;
    payload: (request: {
        indexName: string;
        params?: any;
        facet?: string | undefined;
        type?: "facet" | undefined;
    }, clientValidation: Required<import("./client.types.js").ClientValidation>, mergedSettings: Required<import("./index.types.js").Settings>) => z.SafeParseReturnType<{
        params: {
            query?: string | undefined;
            attributesToRetrieve?: string[] | undefined;
            facetFilters?: string[] | string[][] | undefined;
            numericFilters?: string[] | undefined;
            facets?: string | string[] | undefined;
            maxValuesPerFacet?: number | undefined;
            sortFacetValuesBy?: "alpha" | "count" | undefined;
            attributesToHighlight?: string[] | undefined;
            highlightPostTag?: string | undefined;
            highlightPreTag?: string | undefined;
            page?: number | undefined;
            hitsPerPage?: number | undefined;
            offset?: number | undefined;
            length?: number | undefined;
            maxFacetHits?: number | undefined;
            facetQuery?: string | undefined;
        };
        indexName: string;
        facet?: string | undefined;
        type?: "facet" | undefined;
    } & {
        params: {
            page?: number | undefined;
            hitsPerPage?: number | undefined;
            offset?: number | undefined;
            length?: number | undefined;
        };
    }, {
        params: {
            query?: string | undefined;
            attributesToRetrieve?: string[] | undefined;
            facetFilters?: string[] | string[][] | undefined;
            numericFilters?: string[] | undefined;
            facets?: string | string[] | undefined;
            maxValuesPerFacet?: number | undefined;
            sortFacetValuesBy?: "alpha" | "count" | undefined;
            attributesToHighlight?: string[] | undefined;
            highlightPostTag?: string | undefined;
            highlightPreTag?: string | undefined;
            page?: number | undefined;
            hitsPerPage?: number | undefined;
            offset?: number | undefined;
            length?: number | undefined;
            maxFacetHits?: number | undefined;
            facetQuery?: string | undefined;
        };
        indexName: string;
        facet?: string | undefined;
        type?: "facet" | undefined;
    } & {
        params: {
            page?: number | undefined;
            hitsPerPage?: number | undefined;
            offset?: number | undefined;
            length?: number | undefined;
        };
    }>;
};
export default _default;
