import { z } from 'zod';
export * from './errors.js';
export * from './pg.js';
/**
 * @description
 * Takes an Array<V>, and a grouping function,
 * and returns a Map of the array grouped by the grouping function.
 *
 * @param list An array of type V.
 * @param keyGetter A Function that takes the the Array type V as an input, and returns a value of type K.
 *                  K is generally intended to be a property key of V.
 *
 * @returns Map of the array grouped by the grouping function.
 */
export declare function groupBy<K, V>(list: Array<V>, keyGetter: (input: V) => K): Map<K, Array<V>>;
export declare const interleave: (arr: any[], x: any) => any[];
/**
 * https://stackoverflow.com/a/56592365/21643056
 */
export declare function pick<T extends object, U extends keyof T>(obj: T, paths: Array<U>): Pick<T, U>;
export declare const parseWithDefault: (value: string | undefined, defaultValue: any) => any;
/**
 * Validation helpers

 */
/**
 * Implements
 * This helps us when we already have TS types and want to make a zod schema.
 * It ensures our schema is compatible with our types.
 * https://github.com/colinhacks/zod/issues/372#issuecomment-1280054492
 * e.g. The package @algolia/client-search has a type called SearchOptions.
 * We pick which properties we want to use - we don't have all the features of Algolia.
 * Then that type is used to create a zod schema.
 * With Implements,
 * - if we miss a property from our schema, we get a type error.
 * - if we add an incorrect property to our schema, we get a type error.
 */
type Implements<Model> = {
    [key in keyof Model]-?: undefined extends Model[key] ? null extends Model[key] ? z.ZodNullableType<z.ZodOptionalType<z.ZodType<Model[key]>>> : z.ZodOptionalType<z.ZodType<Model[key]>> : null extends Model[key] ? z.ZodNullableType<z.ZodType<Model[key]>> : z.ZodType<Model[key]>;
};
export declare function implement<Model = never>(): {
    with: <Schema extends Implements<Model> & { [unknownKey in Exclude<keyof Schema, keyof Model>]: never; }>(schema: Schema) => z.ZodObject<Schema, "strip", z.ZodTypeAny, z.objectUtil.addQuestionMarks<z.baseObjectOutputType<Schema>, (z.baseObjectOutputType<Schema> extends infer T_2 ? { [k_2 in keyof T_2]: undefined extends z.baseObjectOutputType<Schema>[k_2] ? never : k_2; } : never)[keyof Schema]> extends infer T ? { [k_1 in keyof T]: z.objectUtil.addQuestionMarks<z.baseObjectOutputType<Schema>, (z.baseObjectOutputType<Schema> extends infer T_1 ? { [k in keyof T_1]: undefined extends z.baseObjectOutputType<Schema>[k] ? never : k; } : never)[keyof Schema]>[k_1]; } : never, z.baseObjectInputType<Schema> extends infer T_3 ? { [k_2 in keyof T_3]: z.baseObjectInputType<Schema>[k_2]; } : never>;
};
/**
 * isIn
 * Used in e.g. schema refinement to check if a client value is in a list of valid values.
 */
export declare const isIn: (val: string | readonly string[], array: string[]) => boolean;
/**
 * undefinedOrLte
 * Used in e.g. schema refinement to check if a client value is less than or equal to a max value.
 */
export declare const undefinedOrLte: (val: number | undefined, max: number) => boolean;
